@@ -25,7 +25,7 @@ class EnviarPedido(Enviar):
         super(EnviarPedido, self).__init__(pedido, dados, configuracao_pagamento)
         self.processa_resposta = True
         self.url = None
-        self.grava_identificador = False
+        self.deve_gravar_dados_de_pagamento = False
 
     def obter_situacao_do_pedido(self, status_requisicao):
         return None
@@ -46,7 +46,8 @@ class EnviarPedido(Enviar):
             self.pedido.data_criacao.date(),
             self.pedido.data_criacao.date() + datetime.timedelta(days=5),
             self.pedido.valor_total,
-            sacado, self.pedido.numero,
+            sacado,
+            self.pedido.numero,
             tipo=self.dados["formato"]
         )
         return {
